#!/usr/bin/perl -w

#*****************************************************************************
#!
#! FILE NAME  : ICQServer.pl
#!
#! PARAMETERS : -p <port number>   - The port to use for the ICQ server
#!              -h                 - Print some help
#!              -v                 - Print some version info
#!
#! DESCRIPTION: Simple ICQ server using ICQServer.pm
#!
#! FUNCTIONS  : die_nicely
#!              print_help
#!
#!----------------------------------------------------------------------------
#! HISTORY
#!
#! DATE         NAME               CHANGES
#! ----         ----               -------
#! Oct  4 1999  Peter Kjellerstedt Initial version
#! 
#!----------------------------------------------------------------------------
#! Copyright (C) 1999, Peter Kjellerstedt & Fredrik Norrman, LUND, SWEDEN
#!****************************************************************************
# %Z% %M% %I% %G%

#****************** INCLUDE FILES SECTION ************************************

use strict;

use Getopt::Std;
use ICQServer;

#****************** VARIABLE DECLARATION SECTION *****************************

use vars qw($port %opt);

#****************** CONSTANT SECTION *****************************************

my $DEBUG = 0;

#****************** MAIN PROGRAM SECTION *************************************

getopts('vhp:', \%opt);

if ($opt{'h'})
{
  # help requested
  &user_help();
  exit;
}

if ($opt{'v'})
{
  # version number
  print "Basic ICQ Server built with " . ICQServer::version() . "\n";
  exit;
}

if ($opt{'p'})
{
  $port = $opt{'p'};

  die "Illegal port! Must be >= 1024...\n" if ($port < 1024);
}

my $ICQServer = new ICQServer $port;
die "Failed to bind to port: $!\n" if (!$ICQServer);


# Set the interrupt handlers
$SIG{INT} = $SIG{TERM} = \&die_nicely;

$DEBUG && warn "DEBUG:  SERVER:  Done binding\n";

while ($ICQServer->incoming_packet_waiting())
{
  $DEBUG && warn "\nDEBUG:  SERVER:  Going to get packet ...\n";
  $ICQServer->incoming_process_packet();
}

print "Server exiting normally.\n";

#****************** FUNCTION DEFINITION SECTION ******************************

#*****************************************************************************
##
## FUNCTION NAME: die_nicely
##
## PARAMETERS   : $signal - The received signal.
##
## RETURNS      : Never.
##
## SIDE EFFECTS : Terminates the program.
##
## DESCRIPTION  : Catch termination of the program.
##
##****************************************************************************

sub die_nicely
{
  my $signal = shift;

  warn "ICQ got signal $signal, exiting.\n";

  exit 1;
}

#*****************************************************************************
##
## FUNCTION NAME: user_help
##
## PARAMETERS   : None.
##
## RETURNS      : Nothing.
##
## SIDE EFFECTS : None.
##
## DESCRIPTION  : Print some help (yeah, right :)
##
##****************************************************************************

sub user_help
{
  print "Use the source, Luke.\n";
  return 1;
}

#****************** END OF FILE ICQServer.pl *********************************
